@@ -1,7 +1,16 @@
+from ast import Store
 import os
+import argparse
 
 
 if __name__=="__main__":
+    # add arg parse
+    parser = argparse.ArgumentParser(description="升级脚本使用说明")
+    parser.add_argument('--update-middle-version', help='increse middle version', action='store_true')
+    parser.add_argument('--update-major-version', help='increse big version', action='store_true')
+    args = parser.parse_args()
+
+
     # check if current git work tree is clean and has no untracked files
     # if yes, checkout to release branch else exit
     if not os.system("git diff --quiet && git diff --cached --quiet"):
@@ -22,7 +31,19 @@ if __name__=="__main__":
             latest_tag_version = latest_tag.split("v")[1]
             # increase the latest tag version
             latest_tag_version = latest_tag_version.split(".")
-            latest_tag_version[-1] = str(int(latest_tag_version[-1]) + 1)
+            # if update major version
+            if args.update_major_version:
+                latest_tag_version[0] = str(int(latest_tag_version[0]) + 1)
+                latest_tag_version[1] = "0"
+                latest_tag_version[2] = "0"
+            # if update middle version
+            elif args.update_middle_version:
+                latest_tag_version[1] = str(int(latest_tag_version[1]) + 1)
+                latest_tag_version[2] = "0"
+            # if update minor version
+            else:
+                latest_tag_version[2] = str(int(latest_tag_version[2]) + 1)
+            # join the latest tag version
             latest_tag_version = ".".join(latest_tag_version)
             # create new tag
             os.system(f"git tag v{latest_tag_version}")
