@@ -38,8 +38,8 @@ def init_subparser(subparsers):
         metavar="STR",
         default="/api/githook/request-artifacts",
     )
-    # add argument "projectID"
-    subparser.add_argument("--projectID", help="project ID", type=str, metavar="STR", required=True)
+    # add argument "project-system-id"
+    subparser.add_argument("--project-system-id", help="project ID", type=str, metavar="STR", required=True)
     # add argument "project-dir"
     subparser.add_argument(
         "--project-dir",
@@ -72,6 +72,10 @@ def init_subparser(subparsers):
         nargs="*",
         default=[],
     )
+    # add argument "--token"
+    subparser.add_argument(
+        "--token", help="download artifacts token", type=str, metavar="STR", required=True
+    )
 
     subparser.add_argument('--restart-docker', help='restart docker after handle update artifacts', action='store_true')
 
@@ -83,12 +87,12 @@ def init_subparser(subparsers):
 def main_process(args):
     upgrade_porcess_root_dir = "/tmp/hc_upgrade_tools"
 
-    project_id = args.projectID
+    project_system_id = args.project_system_id
     original_artifacts_download_dir = os.path.join(upgrade_porcess_root_dir, "artifacts")
     artifact_name = "artifact.zip"
 
     artifacts_path = util.download_artifact(
-        args.host, args.port, args.resource_path, project_id, original_artifacts_download_dir, artifact_name
+        args.host, args.port, args.resource_path, project_system_id, original_artifacts_download_dir, artifact_name, args.token
     )
     _logger.debug(f"artifacts_path: {artifacts_path}")
     _logger.debug(f"upgrade_porcess_root_dir: {upgrade_porcess_root_dir}")
