@@ -134,6 +134,7 @@ def handle_artifacts(source_file_path, target_dir, source_sub_folder=None):
       target_dir (str): 目标目录
       source_sub_folder (str): 指定只需要的交付物中的子目录
     """
+    import tarfile
     logger = get_logger()
 
     if os.path.exists(target_dir):
@@ -144,20 +145,21 @@ def handle_artifacts(source_file_path, target_dir, source_sub_folder=None):
 
     # source file is a zip file
     # unzip source file to target dir, handle exceptions
+    # try zipfile or tarfile
+
     try:
-        import zipfile
-        with zipfile.ZipFile(source_file_path) as z:
+        with tarfile.open(source_file_path, "r:gz") as tar_ref:
             temp_target_dir = os.path.join(target_dir, "tmp")
 
 
             if not source_sub_folder:
-                z.extractall(target_dir)
+                tar_ref.extractall(target_dir)
             else:
                 if not os.path.exists(temp_target_dir):
                     os.makedirs(temp_target_dir)
                 # temp target dir is target dir + "tmp"
                 # clean temp target dir
-                z.extractall(temp_target_dir)
+                tar_ref.extractall(temp_target_dir)
                 # move all files in temp_target_dir/source_sub_dir to target_dir
                 for file in os.listdir(os.path.join(temp_target_dir, source_sub_folder)):
                     os.rename(os.path.join(temp_target_dir, source_sub_folder, file), os.path.join(target_dir, file))
